==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_entities/workorder_001/AllWorkOrder.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderCore"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderBase" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderHealthcare" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderHospitality" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderCore",
    "workOrderBase",
    "workOrderHealthcare",
    "workOrderHospitality"
})
@XmlRootElement(name = "AllWorkOrder")
public class AllWorkOrder {

    @XmlElement(name = "WorkOrderCore", required = true)
    protected WorkOrderCore workOrderCore;
    @XmlElement(name = "WorkOrderBase")
    protected WorkOrderBase workOrderBase;
    @XmlElement(name = "WorkOrderHealthcare")
    protected WorkOrderHealthcare workOrderHealthcare;
    @XmlElement(name = "WorkOrderHospitality")
    protected WorkOrderHospitality workOrderHospitality;

    /**
     * Obtient la valeur de la propriété workOrderCore.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderCore }
     *     
     */
    public WorkOrderCore getWorkOrderCore() {
        return workOrderCore;
    }

    /**
     * Définit la valeur de la propriété workOrderCore.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderCore }
     *     
     */
    public void setWorkOrderCore(WorkOrderCore value) {
        this.workOrderCore = value;
    }

    /**
     * Obtient la valeur de la propriété workOrderBase.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderBase }
     *     
     */
    public WorkOrderBase getWorkOrderBase() {
        return workOrderBase;
    }

    /**
     * Définit la valeur de la propriété workOrderBase.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderBase }
     *     
     */
    public void setWorkOrderBase(WorkOrderBase value) {
        this.workOrderBase = value;
    }

    /**
     * Obtient la valeur de la propriété workOrderHealthcare.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderHealthcare }
     *     
     */
    public WorkOrderHealthcare getWorkOrderHealthcare() {
        return workOrderHealthcare;
    }

    /**
     * Définit la valeur de la propriété workOrderHealthcare.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderHealthcare }
     *     
     */
    public void setWorkOrderHealthcare(WorkOrderHealthcare value) {
        this.workOrderHealthcare = value;
    }

    /**
     * Obtient la valeur de la propriété workOrderHospitality.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderHospitality }
     *     
     */
    public WorkOrderHospitality getWorkOrderHospitality() {
        return workOrderHospitality;
    }

    /**
     * Définit la valeur de la propriété workOrderHospitality.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderHospitality }
     *     
     */
    public void setWorkOrderHospitality(WorkOrderHospitality value) {
        this.workOrderHospitality = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/workorder_001/AllWorkOrder.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderCore"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderBase" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderHealthcare" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrder_001}WorkOrderHospitality" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderCore",
    "workOrderBase",
    "workOrderHealthcare",
    "workOrderHospitality"
})
@XmlRootElement(name = "AllWorkOrder")
public class AllWorkOrder {

    @XmlElement(name = "WorkOrderCore", required = true)
    protected WorkOrderCore workOrderCore;
    @XmlElement(name = "WorkOrderBase")
    protected WorkOrderBase workOrderBase;
    @XmlElement(name = "WorkOrderHealthcare")
    protected WorkOrderHealthcare workOrderHealthcare;
    @XmlElement(name = "WorkOrderHospitality")
    protected WorkOrderHospitality workOrderHospitality;

    /**
     * Gets the value of the workOrderCore property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderCore }
     *     
     */
    public WorkOrderCore getWorkOrderCore() {
        return workOrderCore;
    }

    /**
     * Sets the value of the workOrderCore property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderCore }
     *     
     */
    public void setWorkOrderCore(WorkOrderCore value) {
        this.workOrderCore = value;
    }

    /**
     * Gets the value of the workOrderBase property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderBase }
     *     
     */
    public WorkOrderBase getWorkOrderBase() {
        return workOrderBase;
    }

    /**
     * Sets the value of the workOrderBase property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderBase }
     *     
     */
    public void setWorkOrderBase(WorkOrderBase value) {
        this.workOrderBase = value;
    }

    /**
     * Gets the value of the workOrderHealthcare property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderHealthcare }
     *     
     */
    public WorkOrderHealthcare getWorkOrderHealthcare() {
        return workOrderHealthcare;
    }

    /**
     * Sets the value of the workOrderHealthcare property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderHealthcare }
     *     
     */
    public void setWorkOrderHealthcare(WorkOrderHealthcare value) {
        this.workOrderHealthcare = value;
    }

    /**
     * Gets the value of the workOrderHospitality property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderHospitality }
     *     
     */
    public WorkOrderHospitality getWorkOrderHospitality() {
        return workOrderHospitality;
    }

    /**
     * Sets the value of the workOrderHospitality property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderHospitality }
     *     
     */
    public void setWorkOrderHospitality(WorkOrderHospitality value) {
        this.workOrderHospitality = value;
    }

}
